---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Development or production environment**
 - OS: [e.g. Ubuntu 18.04]
 - Python 3

**Additional context**
Add any other context about the problem here.
